(swagger-spec x)(swagger-spec x options)Transforms data into a swagger2 spec. Input data must conform
to the Swagger2 Spec (http://swagger.io/specification/) with a
exception that it can have any qualified keywords that are expanded
with the schema-tools.swagger.core/expand multimethod.
Transforms data into a swagger2 spec. Input data must conform to the Swagger2 Spec (http://swagger.io/specification/) with a exception that it can have any qualified keywords that are expanded with the `schema-tools.swagger.core/expand` multimethod.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |