schema-tools.util


dissoc-inclj/s

(dissoc-in m [k & ks])

Dissociates an entry from a nested associative structure returning a new nested structure. keys is a sequence of keys. Any empty maps that result will not be present in the new structure.

Dissociates an entry from a nested associative structure returning a new
nested structure. keys is a sequence of keys. Any empty maps that result
will not be present in the new structure.
sourceraw docstring

map-keysclj/s

(map-keys f m)
source

path-valsclj/s

(path-vals m)
(path-vals m fk)

Returns vector of tuples containing path vector to the value and the value.

Returns vector of tuples containing path vector to the value and the value.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries